Motion Event Provider — Kivy v1.0.1-dev documentation

# Motion Event Provider

Abstract class for a implement a `MotionEvent` provider. The implementation must support the `start()`, `stop()` and `update()` methods.

class `kivy.input.provider.` `MotionEventProvider`(device, args)

  Bases: `object`

  Base class for a provider.

  `start`()

    Start the provider. This method is automatically called when the application is started, and if the configuration use the current provider.

  `stop`()

    Stop the provider

  `update`(dispatch_fn)

    Update the provider, and dispatch all the new touch event though the dispatch_fn argument.